@@ -13,13 +13,19 @@ log = logging.getLogger('prom2teams_app')
 
 app = Flask(__name__)
 
-
-
 @app.route('/favicon.ico')
 def favicon():
     return send_from_directory(os.path.join(app.root_path, 'static'),
                                'favicon.ico', mimetype='image/vnd.microsoft.icon')
 
+@app.route('/alive')
+def alive():
+    return "YES", 200
+
+@app.route('/ready')
+def ready():
+    return ("YES", 200) if app.config['FINISH_INIT'] else ("NO", 503)
+
 def error_handler(e):
     msg = 'An unhandled exception occurred. {}'.format(e)
     log.exception(msg)
@@ -42,7 +48,7 @@ def init_app(application):
     register_api(application, api_v1, ns_v1, blueprint_v1)
     register_api(application, api_v2, ns_v2, blueprint_v2)
     application.register_error_handler(500, error_handler)
-
+    application.config['FINISH_INIT'] = True
 
 init_app(app)
 log.info('{} started on {}:{}'.format(app.config['APP_NAME'], app.config['HOST'], app.config['PORT']))
