@@ -39,7 +39,8 @@ class MessageSchema(Schema):
             name = alert['labels']['alertname']
             description = alert['annotations']['description']
             severity = alert['labels']['severity']
-            fingerprint = alert.get('fingerprint', None)
+            runbook_url = alert['annotations'].get('runbook_url', '')
+            fingerprint = alert.get('fingerprint', '')
             extra_labels = dict()
             extra_annotations = dict()
 
@@ -57,7 +58,7 @@ class MessageSchema(Schema):
                 if key not in excluded_annotations and annotation_is_not_dict:
                     extra_annotations[key] = annotation
 
-            alert = PrometheusAlert(name, status, severity, summary, instance, description, fingerprint, extra_labels, extra_annotations)
+            alert = PrometheusAlert(name, status, severity, summary, instance, description, fingerprint, runbook_url, extra_labels, extra_annotations)
             prom_alerts.append(alert)
         return prom_alerts
 
@@ -89,7 +90,7 @@ class AnnotationSchema(Schema):
 
 
 class PrometheusAlert:
-    def __init__(self, name, status, severity, summary, instance, description, fingerprint, extra_labels=None, extra_annotations=None):
+    def __init__(self, name, status, severity, summary, instance, description, fingerprint, runbook_url, extra_labels=None, extra_annotations=None):
         self.name = name
         self.status = status
         self.severity = severity
@@ -97,5 +98,6 @@ class PrometheusAlert:
         self.instance = instance
         self.description = description
         self.fingerprint = fingerprint
+        self.runbook_url = runbook_url
         self.extra_labels = extra_labels
         self.extra_annotations = extra_annotations
